# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: media_and_files.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='media_and_files.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\x15media_and_files.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x15scalapb/scalapb.proto\"Q\n\x0c\x46ileLocation\x12\x1e\n\x07\x66ile_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\"\xaa\x01\n\rImageLocation\x12:\n\rfile_location\x18\x01 \x01(\x0b\x32\x14.dialog.FileLocationB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05width\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x06height\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tfile_size\x18\x04 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\xb0\x01\n\rAudioLocation\x12:\n\rfile_location\x18\x01 \x01(\x0b\x32\x14.dialog.FileLocationB\r\x8a\xea\x30\t\n\x07visible\x12\x1f\n\x08\x64uration\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tmime_type\x18\x03 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12 \n\tfile_size\x18\x04 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\xa8\x01\n\x0b\x41vatarImage\x12:\n\rfile_location\x18\x01 \x01(\x0b\x32\x14.dialog.FileLocationB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05width\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x06height\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tfile_size\x18\x04 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\xb2\x01\n\x06\x41vatar\x12\x37\n\x0bsmall_image\x18\x01 \x01(\x0b\x32\x13.dialog.AvatarImageB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x37\n\x0blarge_image\x18\x02 \x01(\x0b\x32\x13.dialog.AvatarImageB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x36\n\nfull_image\x18\x03 \x01(\x0b\x32\x13.dialog.AvatarImageB\r\x8a\xea\x30\t\n\x07\x63ompact\"]\n\tFastThumb\x12\x18\n\x01w\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x18\n\x01h\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05thumb\x18\x03 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07\x63ompact\"_\n\x05\x43olor\x12\x1f\n\x03rgb\x18\x01 \x01(\x0b\x32\x10.dialog.RgbColorH\x00\x12-\n\npredefined\x18\x02 \x01(\x0b\x32\x17.dialog.PredefinedColorH\x00\x42\x06\n\x04\x62ody\"&\n\x08RgbColor\x12\x1a\n\x03rgb\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\">\n\x0fPredefinedColor\x12+\n\x05\x63olor\x18\x01 \x01(\x0e\x32\x0e.dialog.ColorsB\x0c\x8a\xea\x30\x08\n\x06hidden\"F\n\nHTTPHeader\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05value\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\"\xf2\x01\n\x12\x46ileUrlDescription\x12\x1e\n\x07\x66ile_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03url\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07timeout\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0cunsigned_url\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12>\n\x14unsigned_url_headers\x18\x05 \x03(\x0b\x32\x12.dialog.HTTPHeaderB\x0c\x8a\xea\x30\x08\n\x06hidden\"d\n\x11RequestGetFileUrl\x12\x31\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x14.dialog.FileLocationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xb7\x01\n\x12ResponseGetFileUrl\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\x12\x32\n\x0cunsigned_url\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\x14unsigned_url_headers\x18\x04 \x03(\x0b\x32\x12.dialog.HTTPHeader:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"e\n\x12RequestGetFileUrls\x12\x31\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x14.dialog.FileLocationB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"c\n\x13ResponseGetFileUrls\x12-\n\tfile_urls\x18\x01 \x03(\x0b\x32\x1a.dialog.FileUrlDescription:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"n\n\x18RequestGetFileUrlBuilder\x12\x34\n\x1esupported_signature_algorithms\x18\x01 \x03(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x93\x01\n\x19ResponseGetFileUrlBuilder\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x0c\n\x04\x61lgo\x18\x02 \x01(\t\x12\x0c\n\x04seed\x18\x05 \x01(\t\x12\x18\n\x10signature_secret\x18\x03 \x01(\x0c\x12\x0f\n\x07timeout\x18\x04 \x01(\x05:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"]\n\x17RequestGetFileUploadUrl\x12$\n\rexpected_size\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"Z\n\x18ResponseGetFileUploadUrl\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x12\n\nupload_key\x18\x02 \x01(\x0c:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"^\n\x17RequestCommitFileUpload\x12\x12\n\nupload_key\x18\x01 \x01(\x0c\x12\x11\n\tfile_name\x18\x02 \x01(\t:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"o\n\x18ResponseCommitFileUpload\x12\x34\n\x16uploaded_file_location\x18\x01 \x01(\x0b\x32\x14.dialog.FileLocation:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\x86\x01\n\x1bRequestGetFileUploadPartUrl\x12\x13\n\x0bpart_number\x18\x01 \x01(\x05\x12\x11\n\tpart_size\x18\x02 \x01(\x05\x12!\n\nupload_key\x18\x03 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07\x63ompact:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"J\n\x1cResponseGetFileUploadPartUrl\x12\x0b\n\x03url\x18\x01 \x01(\t:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse*Q\n\x06\x43olors\x12\x12\n\x0e\x43OLORS_UNKNOWN\x10\x00\x12\x0e\n\nCOLORS_RED\x10\x01\x12\x11\n\rCOLORS_YELLOW\x10\x02\x12\x10\n\x0c\x43OLORS_GREEN\x10\x03\x32\xbd\x06\n\rMediaAndFiles\x12q\n\nGetFileUrl\x12\x19.dialog.RequestGetFileUrl\x1a\x1a.dialog.ResponseGetFileUrl\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/MediaAndFiles/GetFileUrl:\x01*\x12u\n\x0bGetFileUrls\x12\x1a.dialog.RequestGetFileUrls\x1a\x1b.dialog.ResponseGetFileUrls\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/grpc/MediaAndFiles/GetFileUrls:\x01*\x12\x8d\x01\n\x11GetFileUrlBuilder\x12 .dialog.RequestGetFileUrlBuilder\x1a!.dialog.ResponseGetFileUrlBuilder\"3\x82\xd3\xe4\x93\x02-\"(/v1/grpc/MediaAndFiles/GetFileUrlBuilder:\x01*\x12\x89\x01\n\x10GetFileUploadUrl\x12\x1f.dialog.RequestGetFileUploadUrl\x1a .dialog.ResponseGetFileUploadUrl\"2\x82\xd3\xe4\x93\x02,\"\'/v1/grpc/MediaAndFiles/GetFileUploadUrl:\x01*\x12\x89\x01\n\x10\x43ommitFileUpload\x12\x1f.dialog.RequestCommitFileUpload\x1a .dialog.ResponseCommitFileUpload\"2\x82\xd3\xe4\x93\x02,\"\'/v1/grpc/MediaAndFiles/CommitFileUpload:\x01*\x12\x99\x01\n\x14GetFileUploadPartUrl\x12#.dialog.RequestGetFileUploadPartUrl\x1a$.dialog.ResponseGetFileUploadPartUrl\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/grpc/MediaAndFiles/GetFileUploadPartUrl:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_COLORS = _descriptor.EnumDescriptor(
  name='Colors',
  full_name='dialog.Colors',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COLORS_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLORS_RED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLORS_YELLOW', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLORS_GREEN', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2900,
  serialized_end=2981,
)
_sym_db.RegisterEnumDescriptor(_COLORS)

Colors = enum_type_wrapper.EnumTypeWrapper(_COLORS)
COLORS_UNKNOWN = 0
COLORS_RED = 1
COLORS_YELLOW = 2
COLORS_GREEN = 3



_FILELOCATION = _descriptor.Descriptor(
  name='FileLocation',
  full_name='dialog.FileLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='dialog.FileLocation.file_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.FileLocation.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=218,
)


_IMAGELOCATION = _descriptor.Descriptor(
  name='ImageLocation',
  full_name='dialog.ImageLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_location', full_name='dialog.ImageLocation.file_location', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width', full_name='dialog.ImageLocation.width', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='dialog.ImageLocation.height', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='dialog.ImageLocation.file_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=391,
)


_AUDIOLOCATION = _descriptor.Descriptor(
  name='AudioLocation',
  full_name='dialog.AudioLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_location', full_name='dialog.AudioLocation.file_location', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='dialog.AudioLocation.duration', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mime_type', full_name='dialog.AudioLocation.mime_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='dialog.AudioLocation.file_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=570,
)


_AVATARIMAGE = _descriptor.Descriptor(
  name='AvatarImage',
  full_name='dialog.AvatarImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_location', full_name='dialog.AvatarImage.file_location', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width', full_name='dialog.AvatarImage.width', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='dialog.AvatarImage.height', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='dialog.AvatarImage.file_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=741,
)


_AVATAR = _descriptor.Descriptor(
  name='Avatar',
  full_name='dialog.Avatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='small_image', full_name='dialog.Avatar.small_image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='large_image', full_name='dialog.Avatar.large_image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_image', full_name='dialog.Avatar.full_image', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=922,
)


_FASTTHUMB = _descriptor.Descriptor(
  name='FastThumb',
  full_name='dialog.FastThumb',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='w', full_name='dialog.FastThumb.w', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h', full_name='dialog.FastThumb.h', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumb', full_name='dialog.FastThumb.thumb', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1017,
)


_COLOR = _descriptor.Descriptor(
  name='Color',
  full_name='dialog.Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rgb', full_name='dialog.Color.rgb', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predefined', full_name='dialog.Color.predefined', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='dialog.Color.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1019,
  serialized_end=1114,
)


_RGBCOLOR = _descriptor.Descriptor(
  name='RgbColor',
  full_name='dialog.RgbColor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rgb', full_name='dialog.RgbColor.rgb', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1116,
  serialized_end=1154,
)


_PREDEFINEDCOLOR = _descriptor.Descriptor(
  name='PredefinedColor',
  full_name='dialog.PredefinedColor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='dialog.PredefinedColor.color', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1156,
  serialized_end=1218,
)


_HTTPHEADER = _descriptor.Descriptor(
  name='HTTPHeader',
  full_name='dialog.HTTPHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.HTTPHeader.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.HTTPHeader.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1220,
  serialized_end=1290,
)


_FILEURLDESCRIPTION = _descriptor.Descriptor(
  name='FileUrlDescription',
  full_name='dialog.FileUrlDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='dialog.FileUrlDescription.file_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.FileUrlDescription.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.FileUrlDescription.timeout', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsigned_url', full_name='dialog.FileUrlDescription.unsigned_url', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsigned_url_headers', full_name='dialog.FileUrlDescription.unsigned_url_headers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1535,
)


_REQUESTGETFILEURL = _descriptor.Descriptor(
  name='RequestGetFileUrl',
  full_name='dialog.RequestGetFileUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='dialog.RequestGetFileUrl.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1537,
  serialized_end=1637,
)


_RESPONSEGETFILEURL = _descriptor.Descriptor(
  name='ResponseGetFileUrl',
  full_name='dialog.ResponseGetFileUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.ResponseGetFileUrl.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.ResponseGetFileUrl.timeout', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsigned_url', full_name='dialog.ResponseGetFileUrl.unsigned_url', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsigned_url_headers', full_name='dialog.ResponseGetFileUrl.unsigned_url_headers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1640,
  serialized_end=1823,
)


_REQUESTGETFILEURLS = _descriptor.Descriptor(
  name='RequestGetFileUrls',
  full_name='dialog.RequestGetFileUrls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='dialog.RequestGetFileUrls.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1825,
  serialized_end=1926,
)


_RESPONSEGETFILEURLS = _descriptor.Descriptor(
  name='ResponseGetFileUrls',
  full_name='dialog.ResponseGetFileUrls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_urls', full_name='dialog.ResponseGetFileUrls.file_urls', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1928,
  serialized_end=2027,
)


_REQUESTGETFILEURLBUILDER = _descriptor.Descriptor(
  name='RequestGetFileUrlBuilder',
  full_name='dialog.RequestGetFileUrlBuilder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='supported_signature_algorithms', full_name='dialog.RequestGetFileUrlBuilder.supported_signature_algorithms', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2029,
  serialized_end=2139,
)


_RESPONSEGETFILEURLBUILDER = _descriptor.Descriptor(
  name='ResponseGetFileUrlBuilder',
  full_name='dialog.ResponseGetFileUrlBuilder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_url', full_name='dialog.ResponseGetFileUrlBuilder.base_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algo', full_name='dialog.ResponseGetFileUrlBuilder.algo', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seed', full_name='dialog.ResponseGetFileUrlBuilder.seed', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature_secret', full_name='dialog.ResponseGetFileUrlBuilder.signature_secret', index=3,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.ResponseGetFileUrlBuilder.timeout', index=4,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2142,
  serialized_end=2289,
)


_REQUESTGETFILEUPLOADURL = _descriptor.Descriptor(
  name='RequestGetFileUploadUrl',
  full_name='dialog.RequestGetFileUploadUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_size', full_name='dialog.RequestGetFileUploadUrl.expected_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2291,
  serialized_end=2384,
)


_RESPONSEGETFILEUPLOADURL = _descriptor.Descriptor(
  name='ResponseGetFileUploadUrl',
  full_name='dialog.ResponseGetFileUploadUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.ResponseGetFileUploadUrl.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_key', full_name='dialog.ResponseGetFileUploadUrl.upload_key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2386,
  serialized_end=2476,
)


_REQUESTCOMMITFILEUPLOAD = _descriptor.Descriptor(
  name='RequestCommitFileUpload',
  full_name='dialog.RequestCommitFileUpload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_key', full_name='dialog.RequestCommitFileUpload.upload_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='dialog.RequestCommitFileUpload.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2478,
  serialized_end=2572,
)


_RESPONSECOMMITFILEUPLOAD = _descriptor.Descriptor(
  name='ResponseCommitFileUpload',
  full_name='dialog.ResponseCommitFileUpload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uploaded_file_location', full_name='dialog.ResponseCommitFileUpload.uploaded_file_location', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2574,
  serialized_end=2685,
)


_REQUESTGETFILEUPLOADPARTURL = _descriptor.Descriptor(
  name='RequestGetFileUploadPartUrl',
  full_name='dialog.RequestGetFileUploadPartUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='part_number', full_name='dialog.RequestGetFileUploadPartUrl.part_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='part_size', full_name='dialog.RequestGetFileUploadPartUrl.part_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_key', full_name='dialog.RequestGetFileUploadPartUrl.upload_key', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2688,
  serialized_end=2822,
)


_RESPONSEGETFILEUPLOADPARTURL = _descriptor.Descriptor(
  name='ResponseGetFileUploadPartUrl',
  full_name='dialog.ResponseGetFileUploadPartUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.ResponseGetFileUploadPartUrl.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2824,
  serialized_end=2898,
)

_IMAGELOCATION.fields_by_name['file_location'].message_type = _FILELOCATION
_AUDIOLOCATION.fields_by_name['file_location'].message_type = _FILELOCATION
_AVATARIMAGE.fields_by_name['file_location'].message_type = _FILELOCATION
_AVATAR.fields_by_name['small_image'].message_type = _AVATARIMAGE
_AVATAR.fields_by_name['large_image'].message_type = _AVATARIMAGE
_AVATAR.fields_by_name['full_image'].message_type = _AVATARIMAGE
_COLOR.fields_by_name['rgb'].message_type = _RGBCOLOR
_COLOR.fields_by_name['predefined'].message_type = _PREDEFINEDCOLOR
_COLOR.oneofs_by_name['body'].fields.append(
  _COLOR.fields_by_name['rgb'])
_COLOR.fields_by_name['rgb'].containing_oneof = _COLOR.oneofs_by_name['body']
_COLOR.oneofs_by_name['body'].fields.append(
  _COLOR.fields_by_name['predefined'])
_COLOR.fields_by_name['predefined'].containing_oneof = _COLOR.oneofs_by_name['body']
_PREDEFINEDCOLOR.fields_by_name['color'].enum_type = _COLORS
_FILEURLDESCRIPTION.fields_by_name['unsigned_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FILEURLDESCRIPTION.fields_by_name['unsigned_url_headers'].message_type = _HTTPHEADER
_REQUESTGETFILEURL.fields_by_name['file'].message_type = _FILELOCATION
_RESPONSEGETFILEURL.fields_by_name['unsigned_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSEGETFILEURL.fields_by_name['unsigned_url_headers'].message_type = _HTTPHEADER
_REQUESTGETFILEURLS.fields_by_name['files'].message_type = _FILELOCATION
_RESPONSEGETFILEURLS.fields_by_name['file_urls'].message_type = _FILEURLDESCRIPTION
_RESPONSECOMMITFILEUPLOAD.fields_by_name['uploaded_file_location'].message_type = _FILELOCATION
DESCRIPTOR.message_types_by_name['FileLocation'] = _FILELOCATION
DESCRIPTOR.message_types_by_name['ImageLocation'] = _IMAGELOCATION
DESCRIPTOR.message_types_by_name['AudioLocation'] = _AUDIOLOCATION
DESCRIPTOR.message_types_by_name['AvatarImage'] = _AVATARIMAGE
DESCRIPTOR.message_types_by_name['Avatar'] = _AVATAR
DESCRIPTOR.message_types_by_name['FastThumb'] = _FASTTHUMB
DESCRIPTOR.message_types_by_name['Color'] = _COLOR
DESCRIPTOR.message_types_by_name['RgbColor'] = _RGBCOLOR
DESCRIPTOR.message_types_by_name['PredefinedColor'] = _PREDEFINEDCOLOR
DESCRIPTOR.message_types_by_name['HTTPHeader'] = _HTTPHEADER
DESCRIPTOR.message_types_by_name['FileUrlDescription'] = _FILEURLDESCRIPTION
DESCRIPTOR.message_types_by_name['RequestGetFileUrl'] = _REQUESTGETFILEURL
DESCRIPTOR.message_types_by_name['ResponseGetFileUrl'] = _RESPONSEGETFILEURL
DESCRIPTOR.message_types_by_name['RequestGetFileUrls'] = _REQUESTGETFILEURLS
DESCRIPTOR.message_types_by_name['ResponseGetFileUrls'] = _RESPONSEGETFILEURLS
DESCRIPTOR.message_types_by_name['RequestGetFileUrlBuilder'] = _REQUESTGETFILEURLBUILDER
DESCRIPTOR.message_types_by_name['ResponseGetFileUrlBuilder'] = _RESPONSEGETFILEURLBUILDER
DESCRIPTOR.message_types_by_name['RequestGetFileUploadUrl'] = _REQUESTGETFILEUPLOADURL
DESCRIPTOR.message_types_by_name['ResponseGetFileUploadUrl'] = _RESPONSEGETFILEUPLOADURL
DESCRIPTOR.message_types_by_name['RequestCommitFileUpload'] = _REQUESTCOMMITFILEUPLOAD
DESCRIPTOR.message_types_by_name['ResponseCommitFileUpload'] = _RESPONSECOMMITFILEUPLOAD
DESCRIPTOR.message_types_by_name['RequestGetFileUploadPartUrl'] = _REQUESTGETFILEUPLOADPARTURL
DESCRIPTOR.message_types_by_name['ResponseGetFileUploadPartUrl'] = _RESPONSEGETFILEUPLOADPARTURL
DESCRIPTOR.enum_types_by_name['Colors'] = _COLORS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FileLocation = _reflection.GeneratedProtocolMessageType('FileLocation', (_message.Message,), dict(
  DESCRIPTOR = _FILELOCATION,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.FileLocation)
  ))
_sym_db.RegisterMessage(FileLocation)

ImageLocation = _reflection.GeneratedProtocolMessageType('ImageLocation', (_message.Message,), dict(
  DESCRIPTOR = _IMAGELOCATION,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ImageLocation)
  ))
_sym_db.RegisterMessage(ImageLocation)

AudioLocation = _reflection.GeneratedProtocolMessageType('AudioLocation', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOLOCATION,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.AudioLocation)
  ))
_sym_db.RegisterMessage(AudioLocation)

AvatarImage = _reflection.GeneratedProtocolMessageType('AvatarImage', (_message.Message,), dict(
  DESCRIPTOR = _AVATARIMAGE,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.AvatarImage)
  ))
_sym_db.RegisterMessage(AvatarImage)

Avatar = _reflection.GeneratedProtocolMessageType('Avatar', (_message.Message,), dict(
  DESCRIPTOR = _AVATAR,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Avatar)
  ))
_sym_db.RegisterMessage(Avatar)

FastThumb = _reflection.GeneratedProtocolMessageType('FastThumb', (_message.Message,), dict(
  DESCRIPTOR = _FASTTHUMB,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.FastThumb)
  ))
_sym_db.RegisterMessage(FastThumb)

Color = _reflection.GeneratedProtocolMessageType('Color', (_message.Message,), dict(
  DESCRIPTOR = _COLOR,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Color)
  ))
_sym_db.RegisterMessage(Color)

RgbColor = _reflection.GeneratedProtocolMessageType('RgbColor', (_message.Message,), dict(
  DESCRIPTOR = _RGBCOLOR,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RgbColor)
  ))
_sym_db.RegisterMessage(RgbColor)

PredefinedColor = _reflection.GeneratedProtocolMessageType('PredefinedColor', (_message.Message,), dict(
  DESCRIPTOR = _PREDEFINEDCOLOR,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.PredefinedColor)
  ))
_sym_db.RegisterMessage(PredefinedColor)

HTTPHeader = _reflection.GeneratedProtocolMessageType('HTTPHeader', (_message.Message,), dict(
  DESCRIPTOR = _HTTPHEADER,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.HTTPHeader)
  ))
_sym_db.RegisterMessage(HTTPHeader)

FileUrlDescription = _reflection.GeneratedProtocolMessageType('FileUrlDescription', (_message.Message,), dict(
  DESCRIPTOR = _FILEURLDESCRIPTION,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.FileUrlDescription)
  ))
_sym_db.RegisterMessage(FileUrlDescription)

RequestGetFileUrl = _reflection.GeneratedProtocolMessageType('RequestGetFileUrl', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETFILEURL,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetFileUrl)
  ))
_sym_db.RegisterMessage(RequestGetFileUrl)

ResponseGetFileUrl = _reflection.GeneratedProtocolMessageType('ResponseGetFileUrl', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETFILEURL,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetFileUrl)
  ))
_sym_db.RegisterMessage(ResponseGetFileUrl)

RequestGetFileUrls = _reflection.GeneratedProtocolMessageType('RequestGetFileUrls', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETFILEURLS,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetFileUrls)
  ))
_sym_db.RegisterMessage(RequestGetFileUrls)

ResponseGetFileUrls = _reflection.GeneratedProtocolMessageType('ResponseGetFileUrls', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETFILEURLS,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetFileUrls)
  ))
_sym_db.RegisterMessage(ResponseGetFileUrls)

RequestGetFileUrlBuilder = _reflection.GeneratedProtocolMessageType('RequestGetFileUrlBuilder', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETFILEURLBUILDER,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetFileUrlBuilder)
  ))
_sym_db.RegisterMessage(RequestGetFileUrlBuilder)

ResponseGetFileUrlBuilder = _reflection.GeneratedProtocolMessageType('ResponseGetFileUrlBuilder', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETFILEURLBUILDER,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetFileUrlBuilder)
  ))
_sym_db.RegisterMessage(ResponseGetFileUrlBuilder)

RequestGetFileUploadUrl = _reflection.GeneratedProtocolMessageType('RequestGetFileUploadUrl', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETFILEUPLOADURL,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetFileUploadUrl)
  ))
_sym_db.RegisterMessage(RequestGetFileUploadUrl)

ResponseGetFileUploadUrl = _reflection.GeneratedProtocolMessageType('ResponseGetFileUploadUrl', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETFILEUPLOADURL,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetFileUploadUrl)
  ))
_sym_db.RegisterMessage(ResponseGetFileUploadUrl)

RequestCommitFileUpload = _reflection.GeneratedProtocolMessageType('RequestCommitFileUpload', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTCOMMITFILEUPLOAD,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestCommitFileUpload)
  ))
_sym_db.RegisterMessage(RequestCommitFileUpload)

ResponseCommitFileUpload = _reflection.GeneratedProtocolMessageType('ResponseCommitFileUpload', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSECOMMITFILEUPLOAD,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseCommitFileUpload)
  ))
_sym_db.RegisterMessage(ResponseCommitFileUpload)

RequestGetFileUploadPartUrl = _reflection.GeneratedProtocolMessageType('RequestGetFileUploadPartUrl', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETFILEUPLOADPARTURL,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetFileUploadPartUrl)
  ))
_sym_db.RegisterMessage(RequestGetFileUploadPartUrl)

ResponseGetFileUploadPartUrl = _reflection.GeneratedProtocolMessageType('ResponseGetFileUploadPartUrl', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETFILEUPLOADPARTURL,
  __module__ = 'media_and_files_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetFileUploadPartUrl)
  ))
_sym_db.RegisterMessage(ResponseGetFileUploadPartUrl)


DESCRIPTOR._options = None
_FILELOCATION.fields_by_name['file_id']._options = None
_FILELOCATION.fields_by_name['access_hash']._options = None
_IMAGELOCATION.fields_by_name['file_location']._options = None
_IMAGELOCATION.fields_by_name['width']._options = None
_IMAGELOCATION.fields_by_name['height']._options = None
_IMAGELOCATION.fields_by_name['file_size']._options = None
_AUDIOLOCATION.fields_by_name['file_location']._options = None
_AUDIOLOCATION.fields_by_name['duration']._options = None
_AUDIOLOCATION.fields_by_name['mime_type']._options = None
_AUDIOLOCATION.fields_by_name['file_size']._options = None
_AVATARIMAGE.fields_by_name['file_location']._options = None
_AVATARIMAGE.fields_by_name['width']._options = None
_AVATARIMAGE.fields_by_name['height']._options = None
_AVATARIMAGE.fields_by_name['file_size']._options = None
_AVATAR.fields_by_name['small_image']._options = None
_AVATAR.fields_by_name['large_image']._options = None
_AVATAR.fields_by_name['full_image']._options = None
_FASTTHUMB.fields_by_name['w']._options = None
_FASTTHUMB.fields_by_name['h']._options = None
_FASTTHUMB.fields_by_name['thumb']._options = None
_RGBCOLOR.fields_by_name['rgb']._options = None
_PREDEFINEDCOLOR.fields_by_name['color']._options = None
_HTTPHEADER.fields_by_name['key']._options = None
_HTTPHEADER.fields_by_name['value']._options = None
_FILEURLDESCRIPTION.fields_by_name['file_id']._options = None
_FILEURLDESCRIPTION.fields_by_name['url']._options = None
_FILEURLDESCRIPTION.fields_by_name['timeout']._options = None
_FILEURLDESCRIPTION.fields_by_name['unsigned_url']._options = None
_FILEURLDESCRIPTION.fields_by_name['unsigned_url_headers']._options = None
_REQUESTGETFILEURL.fields_by_name['file']._options = None
_REQUESTGETFILEURL._options = None
_RESPONSEGETFILEURL._options = None
_REQUESTGETFILEURLS.fields_by_name['files']._options = None
_REQUESTGETFILEURLS._options = None
_RESPONSEGETFILEURLS._options = None
_REQUESTGETFILEURLBUILDER.fields_by_name['supported_signature_algorithms']._options = None
_REQUESTGETFILEURLBUILDER._options = None
_RESPONSEGETFILEURLBUILDER._options = None
_REQUESTGETFILEUPLOADURL.fields_by_name['expected_size']._options = None
_REQUESTGETFILEUPLOADURL._options = None
_RESPONSEGETFILEUPLOADURL._options = None
_REQUESTCOMMITFILEUPLOAD._options = None
_RESPONSECOMMITFILEUPLOAD._options = None
_REQUESTGETFILEUPLOADPARTURL.fields_by_name['upload_key']._options = None
_REQUESTGETFILEUPLOADPARTURL._options = None
_RESPONSEGETFILEUPLOADPARTURL._options = None

_MEDIAANDFILES = _descriptor.ServiceDescriptor(
  name='MediaAndFiles',
  full_name='dialog.MediaAndFiles',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2984,
  serialized_end=3813,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetFileUrl',
    full_name='dialog.MediaAndFiles.GetFileUrl',
    index=0,
    containing_service=None,
    input_type=_REQUESTGETFILEURL,
    output_type=_RESPONSEGETFILEURL,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/MediaAndFiles/GetFileUrl:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetFileUrls',
    full_name='dialog.MediaAndFiles.GetFileUrls',
    index=1,
    containing_service=None,
    input_type=_REQUESTGETFILEURLS,
    output_type=_RESPONSEGETFILEURLS,
    serialized_options=_b('\202\323\344\223\002\'\"\"/v1/grpc/MediaAndFiles/GetFileUrls:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetFileUrlBuilder',
    full_name='dialog.MediaAndFiles.GetFileUrlBuilder',
    index=2,
    containing_service=None,
    input_type=_REQUESTGETFILEURLBUILDER,
    output_type=_RESPONSEGETFILEURLBUILDER,
    serialized_options=_b('\202\323\344\223\002-\"(/v1/grpc/MediaAndFiles/GetFileUrlBuilder:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetFileUploadUrl',
    full_name='dialog.MediaAndFiles.GetFileUploadUrl',
    index=3,
    containing_service=None,
    input_type=_REQUESTGETFILEUPLOADURL,
    output_type=_RESPONSEGETFILEUPLOADURL,
    serialized_options=_b('\202\323\344\223\002,\"\'/v1/grpc/MediaAndFiles/GetFileUploadUrl:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CommitFileUpload',
    full_name='dialog.MediaAndFiles.CommitFileUpload',
    index=4,
    containing_service=None,
    input_type=_REQUESTCOMMITFILEUPLOAD,
    output_type=_RESPONSECOMMITFILEUPLOAD,
    serialized_options=_b('\202\323\344\223\002,\"\'/v1/grpc/MediaAndFiles/CommitFileUpload:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetFileUploadPartUrl',
    full_name='dialog.MediaAndFiles.GetFileUploadPartUrl',
    index=5,
    containing_service=None,
    input_type=_REQUESTGETFILEUPLOADPARTURL,
    output_type=_RESPONSEGETFILEUPLOADPARTURL,
    serialized_options=_b('\202\323\344\223\0020\"+/v1/grpc/MediaAndFiles/GetFileUploadPartUrl:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_MEDIAANDFILES)

DESCRIPTOR.services_by_name['MediaAndFiles'] = _MEDIAANDFILES

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import privacy_pb2 as privacy__pb2


class PrivacyStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.BlockUser = channel.unary_unary(
        '/dialog.Privacy/BlockUser',
        request_serializer=privacy__pb2.RequestBlockUser.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.UnblockUser = channel.unary_unary(
        '/dialog.Privacy/UnblockUser',
        request_serializer=privacy__pb2.RequestUnblockUser.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.LoadBlockedUsers = channel.unary_unary(
        '/dialog.Privacy/LoadBlockedUsers',
        request_serializer=privacy__pb2.RequestLoadBlockedUsers.SerializeToString,
        response_deserializer=privacy__pb2.ResponseLoadBlockedUsers.FromString,
        )


class PrivacyServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def BlockUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnblockUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadBlockedUsers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_PrivacyServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'BlockUser': grpc.unary_unary_rpc_method_handler(
          servicer.BlockUser,
          request_deserializer=privacy__pb2.RequestBlockUser.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'UnblockUser': grpc.unary_unary_rpc_method_handler(
          servicer.UnblockUser,
          request_deserializer=privacy__pb2.RequestUnblockUser.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'LoadBlockedUsers': grpc.unary_unary_rpc_method_handler(
          servicer.LoadBlockedUsers,
          request_deserializer=privacy__pb2.RequestLoadBlockedUsers.FromString,
          response_serializer=privacy__pb2.ResponseLoadBlockedUsers.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Privacy', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config_sync.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='config_sync.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\x11\x63onfig_sync.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x15scalapb/scalapb.proto\"D\n\tParameter\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05value\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\"4\n\x14RequestGetParameters:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"]\n\x15ResponseGetParameters\x12%\n\nparameters\x18\x01 \x03(\x0b\x32\x11.dialog.Parameter:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\x8b\x01\n\x14RequestEditParameter\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"o\n\x16UpdateParameterChanged\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden2\xfa\x01\n\nConfigSync\x12z\n\rGetParameters\x12\x1c.dialog.RequestGetParameters\x1a\x1d.dialog.ResponseGetParameters\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/ConfigSync/GetParameters:\x01*\x12p\n\rEditParameter\x12\x1c.dialog.RequestEditParameter\x1a\x13.dialog.ResponseSeq\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/ConfigSync/EditParameter:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='dialog.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.Parameter.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.Parameter.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=222,
)


_REQUESTGETPARAMETERS = _descriptor.Descriptor(
  name='RequestGetParameters',
  full_name='dialog.RequestGetParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=276,
)


_RESPONSEGETPARAMETERS = _descriptor.Descriptor(
  name='ResponseGetParameters',
  full_name='dialog.ResponseGetParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameters', full_name='dialog.ResponseGetParameters.parameters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=371,
)


_REQUESTEDITPARAMETER = _descriptor.Descriptor(
  name='RequestEditParameter',
  full_name='dialog.RequestEditParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.RequestEditParameter.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.RequestEditParameter.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=374,
  serialized_end=513,
)


_UPDATEPARAMETERCHANGED = _descriptor.Descriptor(
  name='UpdateParameterChanged',
  full_name='dialog.UpdateParameterChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.UpdateParameterChanged.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.UpdateParameterChanged.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=626,
)

_RESPONSEGETPARAMETERS.fields_by_name['parameters'].message_type = _PARAMETER
_REQUESTEDITPARAMETER.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEPARAMETERCHANGED.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['RequestGetParameters'] = _REQUESTGETPARAMETERS
DESCRIPTOR.message_types_by_name['ResponseGetParameters'] = _RESPONSEGETPARAMETERS
DESCRIPTOR.message_types_by_name['RequestEditParameter'] = _REQUESTEDITPARAMETER
DESCRIPTOR.message_types_by_name['UpdateParameterChanged'] = _UPDATEPARAMETERCHANGED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETER,
  __module__ = 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Parameter)
  ))
_sym_db.RegisterMessage(Parameter)

RequestGetParameters = _reflection.GeneratedProtocolMessageType('RequestGetParameters', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETPARAMETERS,
  __module__ = 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetParameters)
  ))
_sym_db.RegisterMessage(RequestGetParameters)

ResponseGetParameters = _reflection.GeneratedProtocolMessageType('ResponseGetParameters', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETPARAMETERS,
  __module__ = 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetParameters)
  ))
_sym_db.RegisterMessage(ResponseGetParameters)

RequestEditParameter = _reflection.GeneratedProtocolMessageType('RequestEditParameter', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTEDITPARAMETER,
  __module__ = 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditParameter)
  ))
_sym_db.RegisterMessage(RequestEditParameter)

UpdateParameterChanged = _reflection.GeneratedProtocolMessageType('UpdateParameterChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEPARAMETERCHANGED,
  __module__ = 'config_sync_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateParameterChanged)
  ))
_sym_db.RegisterMessage(UpdateParameterChanged)


DESCRIPTOR._options = None
_PARAMETER.fields_by_name['key']._options = None
_PARAMETER.fields_by_name['value']._options = None
_REQUESTGETPARAMETERS._options = None
_RESPONSEGETPARAMETERS._options = None
_REQUESTEDITPARAMETER.fields_by_name['key']._options = None
_REQUESTEDITPARAMETER.fields_by_name['value']._options = None
_REQUESTEDITPARAMETER._options = None
_UPDATEPARAMETERCHANGED.fields_by_name['key']._options = None
_UPDATEPARAMETERCHANGED.fields_by_name['value']._options = None

_CONFIGSYNC = _descriptor.ServiceDescriptor(
  name='ConfigSync',
  full_name='dialog.ConfigSync',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=629,
  serialized_end=879,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetParameters',
    full_name='dialog.ConfigSync.GetParameters',
    index=0,
    containing_service=None,
    input_type=_REQUESTGETPARAMETERS,
    output_type=_RESPONSEGETPARAMETERS,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/ConfigSync/GetParameters:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='EditParameter',
    full_name='dialog.ConfigSync.EditParameter',
    index=1,
    containing_service=None,
    input_type=_REQUESTEDITPARAMETER,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/ConfigSync/EditParameter:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CONFIGSYNC)

DESCRIPTOR.services_by_name['ConfigSync'] = _CONFIGSYNC

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import authentication_pb2 as authentication__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class AuthenticationStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.StartPhoneAuth = channel.unary_unary(
        '/dialog.Authentication/StartPhoneAuth',
        request_serializer=authentication__pb2.RequestStartPhoneAuth.SerializeToString,
        response_deserializer=authentication__pb2.ResponseStartPhoneAuth.FromString,
        )
    self.SendCodeByPhoneCall = channel.unary_unary(
        '/dialog.Authentication/SendCodeByPhoneCall',
        request_serializer=authentication__pb2.RequestSendCodeByPhoneCall.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.StartEmailAuth = channel.unary_unary(
        '/dialog.Authentication/StartEmailAuth',
        request_serializer=authentication__pb2.RequestStartEmailAuth.SerializeToString,
        response_deserializer=authentication__pb2.ResponseStartEmailAuth.FromString,
        )
    self.StartAnonymousAuth = channel.unary_unary(
        '/dialog.Authentication/StartAnonymousAuth',
        request_serializer=authentication__pb2.RequestStartAnonymousAuth.SerializeToString,
        response_deserializer=authentication__pb2.ResponseAuth.FromString,
        )
    self.StartTokenAuth = channel.unary_unary(
        '/dialog.Authentication/StartTokenAuth',
        request_serializer=authentication__pb2.RequestStartTokenAuth.SerializeToString,
        response_deserializer=authentication__pb2.ResponseAuth.FromString,
        )
    self.StartUsernameAuth = channel.unary_unary(
        '/dialog.Authentication/StartUsernameAuth',
        request_serializer=authentication__pb2.RequestStartUsernameAuth.SerializeToString,
        response_deserializer=authentication__pb2.ResponseStartUsernameAuth.FromString,
        )
    self.ValidateCode = channel.unary_unary(
        '/dialog.Authentication/ValidateCode',
        request_serializer=authentication__pb2.RequestValidateCode.SerializeToString,
        response_deserializer=authentication__pb2.ResponseAuth.FromString,
        )
    self.ResendCode = channel.unary_unary(
        '/dialog.Authentication/ResendCode',
        request_serializer=authentication__pb2.RequestResendCode.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.ValidatePassword = channel.unary_unary(
        '/dialog.Authentication/ValidatePassword',
        request_serializer=authentication__pb2.RequestValidatePassword.SerializeToString,
        response_deserializer=authentication__pb2.ResponseAuth.FromString,
        )
    self.GetOAuth2Params = channel.unary_unary(
        '/dialog.Authentication/GetOAuth2Params',
        request_serializer=authentication__pb2.RequestGetOAuth2Params.SerializeToString,
        response_deserializer=authentication__pb2.ResponseGetOAuth2Params.FromString,
        )
    self.CompleteOAuth2 = channel.unary_unary(
        '/dialog.Authentication/CompleteOAuth2',
        request_serializer=authentication__pb2.RequestCompleteOAuth2.SerializeToString,
        response_deserializer=authentication__pb2.ResponseAuth.FromString,
        )
    self.SignUp = channel.unary_unary(
        '/dialog.Authentication/SignUp',
        request_serializer=authentication__pb2.RequestSignUp.SerializeToString,
        response_deserializer=authentication__pb2.ResponseAuth.FromString,
        )
    self.GetAuthSessions = channel.unary_unary(
        '/dialog.Authentication/GetAuthSessions',
        request_serializer=authentication__pb2.RequestGetAuthSessions.SerializeToString,
        response_deserializer=authentication__pb2.ResponseGetAuthSessions.FromString,
        )
    self.TerminateSession = channel.unary_unary(
        '/dialog.Authentication/TerminateSession',
        request_serializer=authentication__pb2.RequestTerminateSession.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.TerminateAllSessions = channel.unary_unary(
        '/dialog.Authentication/TerminateAllSessions',
        request_serializer=authentication__pb2.RequestTerminateAllSessions.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.SignOut = channel.unary_unary(
        '/dialog.Authentication/SignOut',
        request_serializer=authentication__pb2.RequestSignOut.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.SignInObsolete = channel.unary_unary(
        '/dialog.Authentication/SignInObsolete',
        request_serializer=authentication__pb2.RequestSignInObsolete.SerializeToString,
        response_deserializer=authentication__pb2.ResponseAuth.FromString,
        )
    self.SignUpObsolete = channel.unary_unary(
        '/dialog.Authentication/SignUpObsolete',
        request_serializer=authentication__pb2.RequestSignUpObsolete.SerializeToString,
        response_deserializer=authentication__pb2.ResponseAuth.FromString,
        )
    self.SendAuthCodeObsolete = channel.unary_unary(
        '/dialog.Authentication/SendAuthCodeObsolete',
        request_serializer=authentication__pb2.RequestSendAuthCodeObsolete.SerializeToString,
        response_deserializer=authentication__pb2.ResponseSendAuthCodeObsolete.FromString,
        )
    self.SendAuthCallObsolete = channel.unary_unary(
        '/dialog.Authentication/SendAuthCallObsolete',
        request_serializer=authentication__pb2.RequestSendAuthCallObsolete.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )


class AuthenticationServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def StartPhoneAuth(self, request, context):
    """/ Start authorization by phone
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SendCodeByPhoneCall(self, request, context):
    """/ Resend code by transaction hash
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartEmailAuth(self, request, context):
    """/ Start email authorization process
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartAnonymousAuth(self, request, context):
    """/ Deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartTokenAuth(self, request, context):
    """/ Start token auth authorization (actual for bots)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartUsernameAuth(self, request, context):
    """/ Start login/password authorization process
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ValidateCode(self, request, context):
    """* Validate code received by phone or email
    Returns error if user does not exist
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ResendCode(self, request, context):
    """/ Resend code if you don't receive it with first attempt
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ValidatePassword(self, request, context):
    """/ Validate your passwword
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetOAuth2Params(self, request, context):
    """/ Deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CompleteOAuth2(self, request, context):
    """/ Deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SignUp(self, request, context):
    """/ Sign up existed user
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetAuthSessions(self, request, context):
    """/ Returns all authorized user's sessions
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TerminateSession(self, request, context):
    """/ Deprecated. Does not produce any effect.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TerminateAllSessions(self, request, context):
    """/ Log out user
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SignOut(self, request, context):
    """/ Log out current session
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SignInObsolete(self, request, context):
    """/ Deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SignUpObsolete(self, request, context):
    """/ Deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SendAuthCodeObsolete(self, request, context):
    """/ Deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SendAuthCallObsolete(self, request, context):
    """/ Deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AuthenticationServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'StartPhoneAuth': grpc.unary_unary_rpc_method_handler(
          servicer.StartPhoneAuth,
          request_deserializer=authentication__pb2.RequestStartPhoneAuth.FromString,
          response_serializer=authentication__pb2.ResponseStartPhoneAuth.SerializeToString,
      ),
      'SendCodeByPhoneCall': grpc.unary_unary_rpc_method_handler(
          servicer.SendCodeByPhoneCall,
          request_deserializer=authentication__pb2.RequestSendCodeByPhoneCall.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'StartEmailAuth': grpc.unary_unary_rpc_method_handler(
          servicer.StartEmailAuth,
          request_deserializer=authentication__pb2.RequestStartEmailAuth.FromString,
          response_serializer=authentication__pb2.ResponseStartEmailAuth.SerializeToString,
      ),
      'StartAnonymousAuth': grpc.unary_unary_rpc_method_handler(
          servicer.StartAnonymousAuth,
          request_deserializer=authentication__pb2.RequestStartAnonymousAuth.FromString,
          response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
      ),
      'StartTokenAuth': grpc.unary_unary_rpc_method_handler(
          servicer.StartTokenAuth,
          request_deserializer=authentication__pb2.RequestStartTokenAuth.FromString,
          response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
      ),
      'StartUsernameAuth': grpc.unary_unary_rpc_method_handler(
          servicer.StartUsernameAuth,
          request_deserializer=authentication__pb2.RequestStartUsernameAuth.FromString,
          response_serializer=authentication__pb2.ResponseStartUsernameAuth.SerializeToString,
      ),
      'ValidateCode': grpc.unary_unary_rpc_method_handler(
          servicer.ValidateCode,
          request_deserializer=authentication__pb2.RequestValidateCode.FromString,
          response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
      ),
      'ResendCode': grpc.unary_unary_rpc_method_handler(
          servicer.ResendCode,
          request_deserializer=authentication__pb2.RequestResendCode.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'ValidatePassword': grpc.unary_unary_rpc_method_handler(
          servicer.ValidatePassword,
          request_deserializer=authentication__pb2.RequestValidatePassword.FromString,
          response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
      ),
      'GetOAuth2Params': grpc.unary_unary_rpc_method_handler(
          servicer.GetOAuth2Params,
          request_deserializer=authentication__pb2.RequestGetOAuth2Params.FromString,
          response_serializer=authentication__pb2.ResponseGetOAuth2Params.SerializeToString,
      ),
      'CompleteOAuth2': grpc.unary_unary_rpc_method_handler(
          servicer.CompleteOAuth2,
          request_deserializer=authentication__pb2.RequestCompleteOAuth2.FromString,
          response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
      ),
      'SignUp': grpc.unary_unary_rpc_method_handler(
          servicer.SignUp,
          request_deserializer=authentication__pb2.RequestSignUp.FromString,
          response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
      ),
      'GetAuthSessions': grpc.unary_unary_rpc_method_handler(
          servicer.GetAuthSessions,
          request_deserializer=authentication__pb2.RequestGetAuthSessions.FromString,
          response_serializer=authentication__pb2.ResponseGetAuthSessions.SerializeToString,
      ),
      'TerminateSession': grpc.unary_unary_rpc_method_handler(
          servicer.TerminateSession,
          request_deserializer=authentication__pb2.RequestTerminateSession.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'TerminateAllSessions': grpc.unary_unary_rpc_method_handler(
          servicer.TerminateAllSessions,
          request_deserializer=authentication__pb2.RequestTerminateAllSessions.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'SignOut': grpc.unary_unary_rpc_method_handler(
          servicer.SignOut,
          request_deserializer=authentication__pb2.RequestSignOut.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'SignInObsolete': grpc.unary_unary_rpc_method_handler(
          servicer.SignInObsolete,
          request_deserializer=authentication__pb2.RequestSignInObsolete.FromString,
          response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
      ),
      'SignUpObsolete': grpc.unary_unary_rpc_method_handler(
          servicer.SignUpObsolete,
          request_deserializer=authentication__pb2.RequestSignUpObsolete.FromString,
          response_serializer=authentication__pb2.ResponseAuth.SerializeToString,
      ),
      'SendAuthCodeObsolete': grpc.unary_unary_rpc_method_handler(
          servicer.SendAuthCodeObsolete,
          request_deserializer=authentication__pb2.RequestSendAuthCodeObsolete.FromString,
          response_serializer=authentication__pb2.ResponseSendAuthCodeObsolete.SerializeToString,
      ),
      'SendAuthCallObsolete': grpc.unary_unary_rpc_method_handler(
          servicer.SendAuthCallObsolete,
          request_deserializer=authentication__pb2.RequestSendAuthCallObsolete.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Authentication', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from .service import ManagedService
from .dialog_api import contacts_pb2, peers_pb2, users_pb2, messaging_pb2


class Users(ManagedService):
    """Class for handling users

    """

    def get_user_outpeer_by_id(self, uid):
        req = messaging_pb2.RequestLoadDialogs(
            min_date=0,
            limit=1,
            peers_to_load=[peers_pb2.Peer(type=peers_pb2.PEERTYPE_PRIVATE, id=uid)]
        )
        result = self.internal.messaging.LoadDialogs(req)

        for outpeer in result.user_peers:
            if outpeer.uid == uid:
                return peers_pb2.OutPeer(
                    type=peers_pb2.PEERTYPE_PRIVATE,
                    id=outpeer.uid,
                    access_hash=outpeer.access_hash
                )

    def find_user_outpeer_by_nick(self, nick):
        """Returns user's Outpeer object by nickname for direct messaging

        :param nick: user's nickname
        :return: Outpeer object of user
        """
        users = self.internal.contacts.SearchContacts(
            contacts_pb2.RequestSearchContacts(
                request=nick
            )
        ).users

        for user in users:
            if user.data.nick.value == nick:
                outpeer = peers_pb2.OutPeer(
                    type=peers_pb2.PEERTYPE_PRIVATE,
                    id=int(user.id),
                    access_hash=int(user.access_hash)
                )
                return outpeer
        return None

    def get_user_by_nick(self, nick):
        """Returns User object by nickname

        :param nick: user's nickname
        :return: User object
        """
        users = self.internal.contacts.SearchContacts(
            contacts_pb2.RequestSearchContacts(
                request=nick
            )
        ).users

        for user in users:
            if user.data.nick.value == nick:
                return user

    def get_user_full_profile_by_nick(self, nick):
        """Returns FullUser object by nickname

        :param nick: user's nickname
        :return: FullUser object
        """
        user = self.find_user_outpeer_by_nick(nick)
        full_profile = self.internal.users.LoadFullUsers(
            users_pb2.RequestLoadFullUsers(
                user_peers=[
                    peers_pb2.UserOutPeer(
                        uid=user.id,
                        access_hash=user.access_hash
                    )
                ]
            )
        )

        if full_profile:
            if hasattr(full_profile, 'full_users'):
                if len(full_profile.full_users) > 0:
                    return full_profile.full_users[0]

    def get_user_custom_profile_by_nick(self, nick):
        """Returns custom_profile field of FullUser object by nickname

        :param nick: user's nickname
        :return: user's custom profile string
        """
        full_profile = self.get_user_full_profile_by_nick(nick)

        if hasattr(full_profile, 'custom_profile'):
            return str(full_profile.custom_profile)

    def get_user_custom_profile_by_peer(self, peer):
        """Returns custom_profile field of FullUser object by Peer object

        :param peer: user's Peer object
        :return: user's custom profile string
        """
        outpeer = self.manager.get_outpeer(peer)

        full_profile = self.internal.users.LoadFullUsers(
            users_pb2.RequestLoadFullUsers(
                user_peers=[
                    peers_pb2.UserOutPeer(
                        uid=outpeer.id,
                        access_hash=outpeer.access_hash
                    )
                ]
            )
        )

        if full_profile:
            if hasattr(full_profile, 'full_users'):
                if len(full_profile.full_users) > 0:
                    if hasattr(full_profile.full_users[0], 'custom_profile'):
                        return str(full_profile.full_users[0].custom_profile)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import stickers_pb2 as stickers__pb2


class StickersStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.LoadOwnStickers = channel.unary_unary(
        '/dialog.Stickers/LoadOwnStickers',
        request_serializer=stickers__pb2.RequestLoadOwnStickers.SerializeToString,
        response_deserializer=stickers__pb2.ResponseLoadOwnStickers.FromString,
        )
    self.LoadAcesssibleStickers = channel.unary_unary(
        '/dialog.Stickers/LoadAcesssibleStickers',
        request_serializer=stickers__pb2.RequestLoadAcesssibleStickers.SerializeToString,
        response_deserializer=stickers__pb2.ResponseLoadAcesssibleStickers.FromString,
        )
    self.AddStickerPackReference = channel.unary_unary(
        '/dialog.Stickers/AddStickerPackReference',
        request_serializer=stickers__pb2.RequestAddStickerPackReference.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.RemoveStickerPackReference = channel.unary_unary(
        '/dialog.Stickers/RemoveStickerPackReference',
        request_serializer=stickers__pb2.RequestRemoveStickerPackReference.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.AddStickerCollection = channel.unary_unary(
        '/dialog.Stickers/AddStickerCollection',
        request_serializer=stickers__pb2.RequestAddStickerCollection.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.RemoveStickerCollection = channel.unary_unary(
        '/dialog.Stickers/RemoveStickerCollection',
        request_serializer=stickers__pb2.RequestRemoveStickerCollection.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.LoadStickerCollection = channel.unary_unary(
        '/dialog.Stickers/LoadStickerCollection',
        request_serializer=stickers__pb2.RequestLoadStickerCollection.SerializeToString,
        response_deserializer=stickers__pb2.ResponseLoadStickerCollection.FromString,
        )


class StickersServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def LoadOwnStickers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadAcesssibleStickers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddStickerPackReference(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveStickerPackReference(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddStickerCollection(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveStickerCollection(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadStickerCollection(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_StickersServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'LoadOwnStickers': grpc.unary_unary_rpc_method_handler(
          servicer.LoadOwnStickers,
          request_deserializer=stickers__pb2.RequestLoadOwnStickers.FromString,
          response_serializer=stickers__pb2.ResponseLoadOwnStickers.SerializeToString,
      ),
      'LoadAcesssibleStickers': grpc.unary_unary_rpc_method_handler(
          servicer.LoadAcesssibleStickers,
          request_deserializer=stickers__pb2.RequestLoadAcesssibleStickers.FromString,
          response_serializer=stickers__pb2.ResponseLoadAcesssibleStickers.SerializeToString,
      ),
      'AddStickerPackReference': grpc.unary_unary_rpc_method_handler(
          servicer.AddStickerPackReference,
          request_deserializer=stickers__pb2.RequestAddStickerPackReference.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'RemoveStickerPackReference': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveStickerPackReference,
          request_deserializer=stickers__pb2.RequestRemoveStickerPackReference.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'AddStickerCollection': grpc.unary_unary_rpc_method_handler(
          servicer.AddStickerCollection,
          request_deserializer=stickers__pb2.RequestAddStickerCollection.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'RemoveStickerCollection': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveStickerCollection,
          request_deserializer=stickers__pb2.RequestRemoveStickerCollection.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'LoadStickerCollection': grpc.unary_unary_rpc_method_handler(
          servicer.LoadStickerCollection,
          request_deserializer=stickers__pb2.RequestLoadStickerCollection.FromString,
          response_serializer=stickers__pb2.ResponseLoadStickerCollection.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Stickers', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from google.protobuf import empty_pb2
import threading
import random
import grpc

from .service import ManagedService
from .dialog_api import messaging_pb2, sequence_and_updates_pb2
from .content import content
from .utils.get_image_metadata import is_image


class Messaging(ManagedService):
    """Main messaging class.

    """
    def send_message(self, peer, text, interactive_media_groups=None):
        """Send text message to current peer. Message can contain interactive media groups (buttons, selects etc.).

        :param peer: receiver's peer
        :param text: message text (not null)
        :param interactive_media_groups: groups of interactive media components (buttons etc.)
        :return: value of SendMessage response object
        """

        if text == '' or text is None:
            raise AttributeError('Text message must contain some text.')

        if not peer:
            print('Peer can\'t be None!')
            return None

        outpeer = self.manager.get_outpeer(peer)
        msg = messaging_pb2.MessageContent()
        msg.textMessage.text = text
        if interactive_media_groups is not None:
            for g in interactive_media_groups:
                media = msg.textMessage.media.add()
                g.render(media)
        return self.internal.messaging.SendMessage(messaging_pb2.RequestSendMessage(
            peer=outpeer,
            deduplication_id=random.randint(0, 100000000),
            message=msg
        ))

    def update_message(self, message, text, interactive_media_groups=None):
        """Update text message or interactive media (buttons, selects etc.).

        :param message object received from any send method (send_message, send_file etc.)
        :param text: message text (not null)
        :param interactive_media_groups: groups of interactive media components (buttons etc.)
        :return: value of UpdateMessage response object
        """
        msg = messaging_pb2.MessageContent()
        msg.textMessage.text = text
        if interactive_media_groups is not None:
            for g in interactive_media_groups:
                media = msg.textMessage.media.add()
                g.render(media)

        return self.internal.messaging.UpdateMessage(messaging_pb2.RequestUpdateMessage(
            mid=message.mid,
            updated_message=msg,
            last_edited_at=message.date
        ))

    def send_file(self, peer, file):
        """Send file to current peer.

        :param peer: receiver's peer
        :param file: path to file
        :return: value of SendMessage response object
        """
        if not peer:
            print('Peer can\'t be None!')
            return None

        location = self.internal.uploading.upload_file(file)
        outpeer = self.manager.get_outpeer(peer)
        msg = messaging_pb2.MessageContent()

        msg.documentMessage.CopyFrom(
            content.get_document_content(file, location)
        )

        return self.internal.messaging.SendMessage(messaging_pb2.RequestSendMessage(
            peer=outpeer,
            deduplication_id=random.randint(0, 100000000),
            message=msg
        ))

    def send_image(self, peer, file):
        """Send image as image (not as file) to current peer.

        :param peer: receiver's peer
        :param file: path to image file
        :return: value of SendMessage response object
        """
        if not peer:
            print('Peer can\'t be None!')
            return None

        if not is_image(file):
            raise IOError('File is not an image.')

        location = self.internal.uploading.upload_file(file)
        outpeer = self.manager.get_outpeer(peer)
        msg = messaging_pb2.MessageContent()

        msg.documentMessage.CopyFrom(
            content.get_image_content(file, location)
        )

        return self.internal.messaging.SendMessage(messaging_pb2.RequestSendMessage(
            peer=outpeer,
            deduplication_id=random.randint(0, 100000000),
            message=msg
        ))

    def load_message_history(self, outpeer, date=0, direction=messaging_pb2.LISTLOADMODE_FORWARD, limit=2):
        if not outpeer:
            print('Outpeer can\'t be None!')
            return None

        return self.internal.messaging.LoadHistory(
            messaging_pb2.RequestLoadHistory(
                peer=outpeer,
                date=date,
                load_mode=direction,
                limit=limit
            )
        )

    def on_message_async(self, callback, interactive_media_callback=None):
        updates_thread = threading.Thread(target=self.on_message, args=(callback, interactive_media_callback))
        updates_thread.start()

    def on_message(self, callback, interactive_media_callback=None, raw_callback=None):
        """Message receiving event handler.

        :param callback: function that will be called when message received
        :param interactive_media_callback: function that will be called when interactive media action is performed
        :param raw_callback: function to handle any other type of update
        :return: None
        """

        while True:
            try:
                for update in self.internal.updates.SeqUpdates(empty_pb2.Empty()):
                    up = sequence_and_updates_pb2.UpdateSeqUpdate()
                    up.ParseFromString(update.update.value)
                    if up.WhichOneof('update') == 'updateMessage':
                        self.internal.messaging.MessageReceived(messaging_pb2.RequestMessageReceived(
                            peer=self.manager.get_outpeer(up.updateMessage.peer),
                            date=up.updateMessage.date
                        ))
                        self.internal.messaging.MessageRead(messaging_pb2.RequestMessageRead(
                            peer=self.manager.get_outpeer(up.updateMessage.peer),
                            date=up.updateMessage.date
                        ))
                        self.internal.thread_pool_executor.submit(
                            callback(up.updateMessage)
                        )
                    elif up.WhichOneof('update') == 'updateInteractiveMediaEvent' and \
                            callable(interactive_media_callback):
                        self.internal.thread_pool_executor.submit(
                            interactive_media_callback(up.updateInteractiveMediaEvent)
                        )
                    else:
                        if callable(raw_callback):
                            self.internal.thread_pool_executor.submit(
                                raw_callback(up)
                            )
            except grpc.RpcError as e:
                if e.details() in ['Socket closed', 'GOAWAY received']:
                    continue



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import device_info_pb2 as device__info__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class DeviceInfoStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.NotifyAboutDeviceInfo = channel.unary_unary(
        '/dialog.DeviceInfo/NotifyAboutDeviceInfo',
        request_serializer=device__info__pb2.RequestNotifyAboutDeviceInfo.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )


class DeviceInfoServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def NotifyAboutDeviceInfo(self, request, context):
    """/ Set info about current device
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DeviceInfoServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'NotifyAboutDeviceInfo': grpc.unary_unary_rpc_method_handler(
          servicer.NotifyAboutDeviceInfo,
          request_deserializer=device__info__pb2.RequestNotifyAboutDeviceInfo.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.DeviceInfo', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import event_bus_pb2 as event__bus__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class EventBusStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.JoinEventBus = channel.unary_unary(
        '/dialog.EventBus/JoinEventBus',
        request_serializer=event__bus__pb2.RequestJoinEventBus.SerializeToString,
        response_deserializer=event__bus__pb2.ResponseJoinEventBus.FromString,
        )
    self.KeepAliveEventBus = channel.unary_unary(
        '/dialog.EventBus/KeepAliveEventBus',
        request_serializer=event__bus__pb2.RequestKeepAliveEventBus.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.PostToEventBus = channel.unary_unary(
        '/dialog.EventBus/PostToEventBus',
        request_serializer=event__bus__pb2.RequestPostToEventBus.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )


class EventBusServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def JoinEventBus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def KeepAliveEventBus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostToEventBus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_EventBusServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'JoinEventBus': grpc.unary_unary_rpc_method_handler(
          servicer.JoinEventBus,
          request_deserializer=event__bus__pb2.RequestJoinEventBus.FromString,
          response_serializer=event__bus__pb2.ResponseJoinEventBus.SerializeToString,
      ),
      'KeepAliveEventBus': grpc.unary_unary_rpc_method_handler(
          servicer.KeepAliveEventBus,
          request_deserializer=event__bus__pb2.RequestKeepAliveEventBus.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'PostToEventBus': grpc.unary_unary_rpc_method_handler(
          servicer.PostToEventBus,
          request_deserializer=event__bus__pb2.RequestPostToEventBus.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.EventBus', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import push_pb2 as push__pb2


class PushStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.RegisterGooglePush = channel.unary_unary(
        '/dialog.Push/RegisterGooglePush',
        request_serializer=push__pb2.RequestRegisterGooglePush.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.UnregisterGooglePush = channel.unary_unary(
        '/dialog.Push/UnregisterGooglePush',
        request_serializer=push__pb2.RequestUnregisterGooglePush.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.RegisterApplePush = channel.unary_unary(
        '/dialog.Push/RegisterApplePush',
        request_serializer=push__pb2.RequestRegisterApplePush.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.UnregisterApplePush = channel.unary_unary(
        '/dialog.Push/UnregisterApplePush',
        request_serializer=push__pb2.RequestUnregisterApplePush.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.RegisterApplePushKit = channel.unary_unary(
        '/dialog.Push/RegisterApplePushKit',
        request_serializer=push__pb2.RequestRegisterApplePushKit.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.UnregisterApplePushKit = channel.unary_unary(
        '/dialog.Push/UnregisterApplePushKit',
        request_serializer=push__pb2.RequestUnregisterApplePushKit.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.RegisterApplePushToken = channel.unary_unary(
        '/dialog.Push/RegisterApplePushToken',
        request_serializer=push__pb2.RequestRegisterApplePushToken.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.UnregisterApplePushToken = channel.unary_unary(
        '/dialog.Push/UnregisterApplePushToken',
        request_serializer=push__pb2.RequestUnregisterApplePushToken.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )


class PushServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def RegisterGooglePush(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnregisterGooglePush(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterApplePush(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnregisterApplePush(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterApplePushKit(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnregisterApplePushKit(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterApplePushToken(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnregisterApplePushToken(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_PushServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'RegisterGooglePush': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterGooglePush,
          request_deserializer=push__pb2.RequestRegisterGooglePush.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'UnregisterGooglePush': grpc.unary_unary_rpc_method_handler(
          servicer.UnregisterGooglePush,
          request_deserializer=push__pb2.RequestUnregisterGooglePush.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'RegisterApplePush': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterApplePush,
          request_deserializer=push__pb2.RequestRegisterApplePush.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'UnregisterApplePush': grpc.unary_unary_rpc_method_handler(
          servicer.UnregisterApplePush,
          request_deserializer=push__pb2.RequestUnregisterApplePush.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'RegisterApplePushKit': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterApplePushKit,
          request_deserializer=push__pb2.RequestRegisterApplePushKit.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'UnregisterApplePushKit': grpc.unary_unary_rpc_method_handler(
          servicer.UnregisterApplePushKit,
          request_deserializer=push__pb2.RequestUnregisterApplePushKit.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'RegisterApplePushToken': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterApplePushToken,
          request_deserializer=push__pb2.RequestRegisterApplePushToken.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'UnregisterApplePushToken': grpc.unary_unary_rpc_method_handler(
          servicer.UnregisterApplePushToken,
          request_deserializer=push__pb2.RequestUnregisterApplePushToken.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Push', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
